"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SendOtpRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    identifier: builtins.str
    def __init__(
        self,
        *,
        identifier: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["identifier", b"identifier"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SendOtpRequest: typing_extensions.TypeAlias = SendOtpRequest

@typing.final
class SendOtpResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["status", b"status"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SendOtpResponse: typing_extensions.TypeAlias = SendOtpResponse

@typing.final
class VerifyOtpRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    OTP_FIELD_NUMBER: builtins.int
    identifier: builtins.str
    otp: builtins.str
    def __init__(
        self,
        *,
        identifier: builtins.str = ...,
        otp: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["identifier", b"identifier", "otp", b"otp"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___VerifyOtpRequest: typing_extensions.TypeAlias = VerifyOtpRequest

@typing.final
class VerifyOtpResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_TOKEN_FIELD_NUMBER: builtins.int
    REFRESH_TOKEN_FIELD_NUMBER: builtins.int
    access_token: builtins.str
    refresh_token: builtins.str
    def __init__(
        self,
        *,
        access_token: builtins.str = ...,
        refresh_token: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["access_token", b"access_token", "refresh_token", b"refresh_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___VerifyOtpResponse: typing_extensions.TypeAlias = VerifyOtpResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: auth.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'auth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x12\x04\x61uth\"$\n\x0eSendOtpRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\"!\n\x0fSendOtpResponse\x12\x0e\n\x06status\x18\x01 \x01(\x08\"3\n\x10VerifyOtpRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0b\n\x03otp\x18\x02 \x01(\t\"@\n\x11VerifyOtpResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t2\x83\x01\n\x0b\x41uthService\x12\x36\n\x07SendOtp\x12\x14.auth.SendOtpRequest\x1a\x15.auth.SendOtpResponse\x12<\n\tVerifyOtp\x12\x16.auth.VerifyOtpRequest\x1a\x17.auth.VerifyOtpResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SENDOTPREQUEST']._serialized_start=20
  _globals['_SENDOTPREQUEST']._serialized_end=56
  _globals['_SENDOTPRESPONSE']._serialized_start=58
  _globals['_SENDOTPRESPONSE']._serialized_end=91
  _globals['_VERIFYOTPREQUEST']._serialized_start=93
  _globals['_VERIFYOTPREQUEST']._serialized_end=144
  _globals['_VERIFYOTPRESPONSE']._serialized_start=146
  _globals['_VERIFYOTPRESPONSE']._serialized_end=210
  _globals['_AUTHSERVICE']._serialized_start=213
  _globals['_AUTHSERVICE']._serialized_end=344
# @@protoc_insertion_point(module_scope)
